.. _bfg_sql_wiki_tutorial:

SQLAlchemy + URL dispatch wiki tutorial
=======================================

This tutorial introduces an :term:`SQLAlchemy` and :term:`URL dispatch`-based
:app:`Pyramid` application to a developer familiar with Python.  When the
tutorial is finished, the developer will have created a basic wiki
application with authentication and authorization.

For cut and paste purposes, the source code for all stages of this tutorial can
be browsed on GitHub at `docs/tutorials/wiki2/src
<https://github.com/Pylons/pyramid/tree/master/docs/tutorials/wiki2/src>`_,
which corresponds to the same location if you have Pyramid sources.

.. toctree::
   :maxdepth: 2

   background
   design
   installation
   basiclayout
   definingmodels
   definingviews
   authentication
   authorization
   tests
   distributing

